@@ -252,7 +252,7 @@ class GenderClientService(MaleoClientService):
 
                 if parameters.use_cache:
                     await self._redis.set(
-                        cache_key, result.model_dump_json(), Expiration.EXP_1WK
+                        cache_key, result.model_dump_json(), Expiration.EXP_1WK.value
                     )
 
                 return result
@@ -414,7 +414,7 @@ class GenderClientService(MaleoClientService):
 
                 if parameters.use_cache:
                     await self._redis.set(
-                        cache_key, result.model_dump_json(), Expiration.EXP_1WK
+                        cache_key, result.model_dump_json(), Expiration.EXP_1WK.value
                     )
 
                 return result
