@@ -267,7 +267,7 @@ class MedicalRoleClientService(MaleoClientService):
 
                 if parameters.use_cache:
                     await self._redis.set(
-                        cache_key, result.model_dump_json(), Expiration.EXP_1WK
+                        cache_key, result.model_dump_json(), Expiration.EXP_1WK.value
                     )
 
                 return result
@@ -450,7 +450,7 @@ class MedicalRoleClientService(MaleoClientService):
 
                 if parameters.use_cache:
                     await self._redis.set(
-                        cache_key, result.model_dump_json(), Expiration.EXP_1WK
+                        cache_key, result.model_dump_json(), Expiration.EXP_1WK.value
                     )
 
                 return result
@@ -623,7 +623,7 @@ class MedicalRoleClientService(MaleoClientService):
 
                 if parameters.use_cache:
                     await self._redis.set(
-                        cache_key, result.model_dump_json(), Expiration.EXP_1WK
+                        cache_key, result.model_dump_json(), Expiration.EXP_1WK.value
                     )
 
                 return result
@@ -806,7 +806,7 @@ class MedicalRoleClientService(MaleoClientService):
 
                 if parameters.use_cache:
                     await self._redis.set(
-                        cache_key, result.model_dump_json(), Expiration.EXP_1WK
+                        cache_key, result.model_dump_json(), Expiration.EXP_1WK.value
                     )
 
                 return result
