@@ -266,7 +266,7 @@ class OrganizationTypeClientService(MaleoClientService):
 
                 if parameters.use_cache:
                     await self._redis.set(
-                        cache_key, result.model_dump_json(), Expiration.EXP_1WK
+                        cache_key, result.model_dump_json(), Expiration.EXP_1WK.value
                     )
 
                 return result
@@ -441,7 +441,7 @@ class OrganizationTypeClientService(MaleoClientService):
 
                 if parameters.use_cache:
                     await self._redis.set(
-                        cache_key, result.model_dump_json(), Expiration.EXP_1WK
+                        cache_key, result.model_dump_json(), Expiration.EXP_1WK.value
                     )
 
                 return result
