@@ -262,7 +262,7 @@ class ServiceClientService(MaleoClientService):
 
                 if parameters.use_cache:
                     await self._redis.set(
-                        cache_key, result.model_dump_json(), Expiration.EXP_1WK
+                        cache_key, result.model_dump_json(), Expiration.EXP_1WK.value
                     )
 
                 return result
@@ -435,7 +435,7 @@ class ServiceClientService(MaleoClientService):
 
                 if parameters.use_cache:
                     await self._redis.set(
-                        cache_key, result.model_dump_json(), Expiration.EXP_1WK
+                        cache_key, result.model_dump_json(), Expiration.EXP_1WK.value
                     )
 
                 return result
