@@ -264,7 +264,7 @@ class SystemRoleClientService(MaleoClientService):
 
                 if parameters.use_cache:
                     await self._redis.set(
-                        cache_key, result.model_dump_json(), Expiration.EXP_1WK
+                        cache_key, result.model_dump_json(), Expiration.EXP_1WK.value
                     )
 
                 return result
@@ -437,7 +437,7 @@ class SystemRoleClientService(MaleoClientService):
 
                 if parameters.use_cache:
                     await self._redis.set(
-                        cache_key, result.model_dump_json(), Expiration.EXP_1WK
+                        cache_key, result.model_dump_json(), Expiration.EXP_1WK.value
                     )
 
                 return result
